@@ -4,8 +4,10 @@ import tornado.web
 
 class Server:
     def __init__(self, proxy_to, ca_file, port, request_timeout, **httpserver_kwargs):
+        circuit_breaker = mallory.CircuitBreaker(proxy_to)
         app = tornado.web.Application([
-            (r"/.*", mallory.RequestHandler, dict(proxy_to=proxy_to, ca_file=ca_file, request_timeout=request_timeout))
+            (r"/_mallory/heartbeat", mallory.HeartbeatHandler, dict(circuit_breaker=circuit_breaker)),
+            (r"/.*", mallory.RequestHandler, dict(circuit_breaker=circuit_breaker, proxy_to=proxy_to, ca_file=ca_file, request_timeout=request_timeout))
         ])
         self.http_server = tornado.httpserver.HTTPServer(app, **httpserver_kwargs)
         self.port = port
